@@ -114,6 +114,30 @@ class Project:
         instance.sanitize_source_indexes()
         return instance
 
+    def set_allow_prereleases(self, allow_prereleases: bool = True) -> None:
+        """Allow or disallow pre-releases for this project."""
+        self.pipfile.meta.pipenv['allow_prereleases'] = allow_prereleases
+
+    @property
+    def prereleases_allowed(self) -> bool:
+        """Check if pre-releases are allowed for this project."""
+        return self.pipfile.meta.pipenv.get('allow_prereleases', False) if self.pipfile.meta.pipenv else False
+
+    def set_python_version(self, python_version: str = None) -> None:
+        """Set version of Python used in the project."""
+        if python_version is None:
+            self.pipfile.meta.requires.pop('python_version')
+        else:
+            if self.pipfile.meta.requires is None:
+                self.pipfile.meta.requires = {}
+
+            self.pipfile.meta.requires['python_version'] = python_version
+
+    @property
+    def python_version(self) -> str:
+        """Get Python version used in this project."""
+        return self.pipfile.meta.requires.get('python_version', None)
+
     def to_dict(self):
         """Create a dictionary representation of this project."""
         return {
@@ -339,7 +363,7 @@ class Project:
                         continue
 
                     artifact_entry = [
-                        (i['name'], i['sha256']) for i in index_info
+                        (i.get('name'), i['sha256']) for i in index_info
                         if i['sha256'] == artifact_hash
                     ]
 
@@ -462,3 +486,28 @@ class Project:
             name=package_name, version=package_version, develop=develop, index=source.name if source else None
         )
         self.pipfile.add_package_version(package_version)
+
+    def test_indexes_in_meta(self):
+        package_version = PackageVersion(
+            name='tensorflow',
+            version='==1.9.0',
+            develop=False,
+            index=Source('http://tensorflow.pypi.thoth-station.ninja/index/fedora28/jemalloc/simple/tensorflow/')
+        )
+
+        project = Project.from_package_versions([package_version])
+        project_dict = project.to_dict()
+
+        pipfile_dict = project.pipfile
+        pipfile_lock_dict = project.pipfile_lock
+
+        assert pipfile_lock_dict is None
+
+        assert len(pipfile_dict['source']) == 1
+        assert pipfile_dict['source'] == [
+            {
+                'url': 'http://tensorflow.pypi.thoth-station.ninja/index/fedora28/jemalloc/simple/tensorflow/',
+                'verify_ssl': True,
+                'name': 'tensorflow'
+            }
+        ]
